@@ -2,11 +2,28 @@ package Yote::Obj;
 
 #
 # This is base Yote Object class. 
-# It is a container class containing key value pairs via getters and setters.
-# To set a value, call $obj->set_foo( $value ); 
-# To get a value, call my $val = $obj->get_foo();
-# Get takes an optional value argument. The value of foo is set to this
-#  if it did not previously have a value.
+#
+# It is a container class with fields and methods.
+#
+# On the server side :
+#
+#   The fields can be accessed with get_, like 'get_foo();' or 'get_foo( $initializer )'
+#      A getter takes an optional initialization object 
+#      that is only used if the field has not yet been defined
+#
+#   The fields can be set with set_ like 'set_foo( "value" )'.
+#    
+#   Lists can be added by by add_to_, like 'add_to_mylist( 'a', 2, $obj );'
+#  
+#   Items can be removed from lists with remove_from_,  like 'remove_from_list( 2 );'        
+#
+# On the client side :
+#
+#   methods may be invoked if they do not start with an underscore.
+#
+#   data may be accessed if it does not start with an underscore
+#
+#   data may be written to if it starts with a capitol letter
 #
 
 use strict;
@@ -30,14 +47,122 @@ sub new {
 
     $obj->{ID} ||= Yote::ObjProvider::get_id( $obj );
     $obj->init() if $needs_init;
-    $obj->_on_load();
 
     return $obj;
 } #new
 
-sub size {
-    return scalar keys %{shift->{DATA}};
-} #size
+#
+# Called the very first time this object is created. It is not called
+# when object is loaded from storage.
+# 
+sub init {}
+
+#
+# Updates the object but only for capitolized keys that already exist.
+# public client method.
+#
+sub update {
+    my( $self, $data, $account ) = @_;
+    my $updated = {};
+    for my $fld (keys %$data) {
+        next unless $fld =~ /^[A-Z]/ && defined( $self->{$fld} );
+        my $inval = Yote::ObjProvider::xform_in( $data->{$fld} );
+        Yote::ObjProvider::dirty( $self, $self->{ID} ) if $self->{DATA}{$fld} ne $inval;
+        $self->{DATA}{$fld} = $inval;
+        $updated->{$fld} = $inval;
+    }
+    return $updated;
+} #update
+
+sub load_direct_descendents {
+    my( $self, $data, $account ) = @_;
+    my @ret;
+    for my $fld (grep { $_ !~ /^_/ } keys %{$self->{DATA}}) {
+        my $val = $self->{DATA}{$fld};
+        next unless $val > 0;
+        push( @ret, Yote::ObjProvider::xform_out( $val ) );
+    }
+    return \@ret;
+} #load_direct_descendents 
+
+#
+# Transforms data structure but does not assign ids to non tied references.
+#
+sub _transform_data_no_id {
+    my( $self, $item, $acct ) = @_;
+    if( ref( $item ) eq 'ARRAY' ) {
+        my $tied = tied @$item;
+        if( $tied ) {
+            return Yote::ObjProvider::get_id( $item ); 
+        }
+        return [map { $self->_obj_to_response( $_, $acct, 1 ) } @$item];
+    }
+    elsif( ref( $item ) eq 'HASH' ) {
+        my $tied = tied %$item;
+        if( $tied ) {
+            return Yote::ObjProvider::get_id( $item ); 
+        }
+        return { map { $_ => $self->_obj_to_response( $item->{$_}, $acct, 1 ) } keys %$item };
+    }
+    elsif( ref( $item ) ) {
+        return  Yote::ObjProvider::get_id( $item ); 
+    }
+    else {
+        return "v$item"; #scalar case
+    }
+} #_transform_data_no_id
+
+#
+# Converts scalar, yote object, hash or array to data for returning.
+#
+sub _obj_to_response {
+    my( $self, $to_convert, $acct, $xform_out ) = @_;
+    my $ref = ref($to_convert);
+    my $use_id;
+    if( $ref ) {
+        my( $m, $d ) = ([]);
+        if( $ref eq 'ARRAY' ) {
+            my $tied = tied @$to_convert;
+            if( $tied ) {
+                $d = $tied->[1];
+                $use_id = Yote::ObjProvider::get_id( $to_convert );
+                if( $acct ) {
+                    $acct->get_login()->get__allowed_access()->{$use_id} = 1;
+                }
+                return $use_id unless $xform_out;
+            } else {
+                $d = $self->_transform_data_no_id( $to_convert, $acct );
+            }
+        } 
+        elsif( $ref eq 'HASH' ) {
+            my $tied = tied %$to_convert;
+            if( $tied ) {
+                $d = $tied->[1];
+                $use_id = Yote::ObjProvider::get_id( $to_convert );
+                if( $acct ) {
+                    $acct->get_login()->get__allowed_access()->{$use_id} = 1;
+                }
+                return $use_id unless $xform_out;
+            } else {
+                $d = $self->_transform_data_no_id( $to_convert, $acct );
+            }
+        } 
+        else {
+            $use_id = Yote::ObjProvider::get_id( $to_convert );
+            if( $acct ) {
+                $acct->get_login()->get__allowed_access()->{$use_id} = 1;
+            }
+            return $use_id unless $xform_out;
+            $d = { map { $_ => $to_convert->{DATA}{$_} } grep { $_ && $_ !~ /^_/ } keys %{$to_convert->{DATA}}};
+
+            $m = Yote::ObjProvider::package_methods( $ref );
+        }
+        return { a => ref( $self ), c => $ref, id => $use_id, d => $d, 'm' => $m };
+    } # if a reference
+    return "v$to_convert" if $xform_out;
+    return $to_convert;
+} #_obj_to_response
+
 
 #
 # Takes the entire key/value pairs of data as field/value pairs attached to this.
@@ -45,37 +170,28 @@ sub size {
 sub _absorb {
     my $self = shift;
     my $data = ref( $_[0] ) ? $_[0] : { @_ };
+
+    my $updated_count = 0;
     for my $fld (keys %$data) {
         my $inval = Yote::ObjProvider::xform_in( $data->{$fld} );
         Yote::ObjProvider::dirty( $self, $self->{ID} ) if $self->{DATA}{$fld} ne $inval;
         $self->{DATA}{$fld} = $inval;
+        ++$updated_count;
     } #each field
-    return undef;
+    return $updated_count;
 } #_absorb
 
 
 # returns true if the object passsed in is the same as this one.
-sub is {
+sub _is {
     my( $self, $obj ) = @_;
     return ref( $obj ) && ref( $obj ) eq ref( $self ) &&
         Yote::ObjProvider::get_id( $obj ) == Yote::ObjProvider::get_id( $self );
 }
 
-# shallow clones this object
-sub clone {
-    my $self = shift;
-    my $class = ref( $self );
-    my $clone = $class->new;
-    for my $field (keys %{$self->{DATA}}) {
-        $clone->{DATA}{$field} = $self->{DATA}{$field};
-    }
-    return $clone;
-} #clone
-
-
-sub init {}
-sub _on_load {}
-
+#
+# Defines get_foo, set_foo, add_to_list, remove_from_list
+#
 sub AUTOLOAD {
     my( $s, $arg ) = @_;
     my $func = our $AUTOLOAD;
